#include "AudioTools.h"
#include "StarWars30.h"
#include <Wire.h>

AudioInfo info(22050, 1, 16);
I2SStream i2s;  // Output to I2S
MemoryStream music(StarWars30_raw, StarWars30_raw_len);
StreamCopy copier(i2s, music); // copies sound into i2s

#define HT513_ADDR_L 0x6c
/**
   @brief  ht513写寄存器
   @param  addr 寄存器地址
   @param  val 要写的值
   @retval None
*/
void HT513_WriteOneByte(uint8_t addr, uint8_t val)
{
  Wire.beginTransmission(HT513_ADDR_L);
  Wire.write(addr);
  Wire.write(val);
  Wire.endTransmission(true);
}

/**
   @brief  ht513读寄存器
   @param  addr 寄存器地址
   @retval 读取到的寄存器值
*/
uint8_t HT513_ReadOneByte(uint8_t addr)
{
  uint8_t temp = 0;

  Wire.beginTransmission(HT513_ADDR_L);
  Wire.write(addr);
  Wire.endTransmission(true);

  Wire.requestFrom(HT513_ADDR_L, (uint8_t)1);
  temp = Wire.read();

  return temp;
}

void setup() {
      Wire.begin(21,22);

  Serial.begin(115200);
  AudioLogger::instance().begin(Serial, AudioLogger::Info);

  auto config = i2s.defaultConfig(TX_MODE);
  config.copyFrom(info);
  i2s.begin(config);
  //  设置 SD 为LOW
  HT513_WriteOneByte(0x12,0b11110000);
  
  // 设置数据格式为 I2S, 16Bits
  HT513_WriteOneByte(0x13, 0b00110000);

  // 调整音量
  HT513_WriteOneByte(0x16, 0b10100000);
  
  //  设置 SD 为LOW
  HT513_WriteOneByte(0x12,0b11110100);

}

void loop() {
  if (!copier.copy()) {
    i2s.end();
    stop();
  }
}
